Index: Source/core/dom/EventTarget.h |
diff --git a/Source/core/dom/EventTarget.h b/Source/core/dom/EventTarget.h |
index 60a9e45a0b4991db8efeda1b441479dd5dd4204e..a5d49941aa74d1bd18c2ab2e5137df4492fa9eeb 100644 |
--- a/Source/core/dom/EventTarget.h |
+++ b/Source/core/dom/EventTarget.h |
@@ -127,12 +127,12 @@ namespace WebCore { |
bool fireEventListeners(Event*); |
bool isFiringEventListeners(); |
// We can't pass an EventTarget pointer into Visitor::visit directly |
// because it does not coincide with the actual start of the object and |
// the visitor has to access the object header. Thus we need a helper |
// method that correctly adjusts the pointer before passing it into the |
// visitor. |
- virtual void visitWith(Visitor*) const = 0; |
+ virtual void adjustAndMark(Visitor*) const = 0; |
protected: |
virtual ~EventTarget(); |
@@ -198,7 +198,7 @@ namespace WebCore { |
template<> class TraceTrait<EventTarget> { |
public: |
- static void visit(Visitor* visitor, const EventTarget* self) { self->visitWith(visitor); } |
+ static void mark(Visitor* visitor, const EventTarget* self) { self->adjustAndMark(visitor); } |
static intptr_t getTypeMarker() { return 0; } |
@@ -127,12 +127,12 @@ namespace WebCore { |
bool fireEventListeners(Event*); |
bool isFiringEventListeners(); |
- // We can't pass an EventTarget pointer into Visitor::visit directly |
+ // We can't pass an EventTarget pointer into Visitor::mark directly |
// because it does not coincide with the actual start of the object and |
// the visitor has to access the object header. Thus we need a helper |